<?php
/**
 * Registers and handles the admin area.
 *
 * @package BPMVP
 */

/**
 * Class BPMVP_Admin
 */
class BPMVP_Admin {

	/**
	 * Plugin instance.
	 *
	 * @see   get_instance()
	 * @var  object
	 */
	protected static $instance = NULL;

	/**
	 * Load the admin interface
	 *
	 * @return void
	 */
	public function load() {

		// Check, if the admin notice should be hidden.
		if (
			current_user_can( 'manage_options' ) &&
			! empty( $_GET['bpmvp-api-key-notice'] ) && // Input var okay.
			wp_verify_nonce( sanitize_key( wp_unslash( $_GET['bpmvp-api-key-notice'] ) ), 'remove-api-key-notice' ) // Input var okay.
		) {
			update_option( 'bpmvp-api-key-invalid', 0 );
		}

		// Check, if the admin notice should be displayed.
		if ( 1 === (int) get_option( 'bpmvp-api-key-invalid' ) ) {
			add_action( 'admin_notices', array( $this, 'show_notice' ) );
		}

		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue' ) );
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'admin_init', array( $this, 'register_settings' ) );
	}

	/**
	 * Shows the admin notice.
	 *
	 * @return void
	 */
	public function show_notice() {
		$url = admin_url( 'options-general.php' );
		$url = add_query_arg(
			array(
				'page'                => 'byteplant_email_validator',
				'bpmvp-api-key-notice' => wp_create_nonce( 'remove-api-key-notice' ),
			),
			$url
		);
		?>
		<div class="notice notice-error">
			<p>
				<?php esc_html_e( 'The API Key is invalid.', 'email-validator-by-byteplant' ); ?>
				<a href="<?php echo esc_url( $url ); ?>"><?php esc_html_e( 'Go to settings and hide message', 'email-validator-by-byteplant' ); ?></a>
			</p>

		</div>
		<?php
	}

	/**
	 * Register the admin menu.
	 *
	 * @return void
	 */
	function admin_menu() {

		add_options_page( __('Byteplant Email Validator', 'email-validator-by-byteplant' ), __('Byteplant Email Validator', 'email-validator-by-byteplant' ), 'manage_options', 'byteplant_email_validator', array( $this, 'render_page' ) );
	}

	/**
	 * Render the page.
	 *
	 * @return void
	 */
	function render_page() {

		?>
		<div class="wrap">
			<h1><?php esc_html_e('Byteplant Email Validator', 'email-validator-by-byteplant' ); ?></h1>
			<form action='options.php' method='post'>
				<?php
				settings_fields( 'byteplant_email_validator' );
				do_settings_sections( 'byteplant_email_validator' );
				submit_button();
				?>
			</form>

			<div class="card bpmvp-card" style="">
				<h2><?php esc_html_e('Validate Email Address', 'email-validator-by-byteplant'); ?></h2>
				<p><?php esc_html_e('Please enter the email address you want to validate.', 'email-validator-by-byteplant'); ?></p>
				<table class="form-table">
					<tbody>
					<tr>
						<th scope="row"><?php esc_html_e('Email', 'email-validator-by-byteplant'); ?></th>
						<td>
							<input id="bpmvp-mail" value="" type="text">
						</td>
					</tr>
					</tbody>
				</table>
				<p id="bpmvp-message"></p>
				<p class="submit">
					<input name="submit" id="bpmvp-button-validate" class="button button-primary" value="<?php echo esc_attr( __('Validate', 'email-validator-by-byteplant') ); ?>" type="submit">
				</p>
				<ul id="bpmvp-list"></ul>
			</div>

		</div>
		<?php
	}

	/**
	 * Enqueue the necessary scripts and styles
	 *
	 * @param string $hook The page hook.
	 *
	 * @return void
	 */
	function enqueue( $hook ) {

		if ( 'settings_page_byteplant_email_validator' !== $hook ) {
			return;
		}

		$plugin = BPMVP_Plugin::get_instance();
		$plugin_url = $plugin->get_plugin_url();

		$min = ( ! $plugin->is_debug() ) ? '.min' : '';

		wp_register_style( 'bpmvp_main_style', $plugin_url . 'assets/css/bpmvp_style' . $min . '.css' );
		wp_register_script('bpmvp_main_script', $plugin_url . 'assets/js/bpmvp_script' . $min . '.js', array( 'jquery', 'underscore' ), '1.0', TRUE );

		$js_vars = $plugin->js_localization();
		$js_vars['ul_tpl'] = '<li><span><%- status %></span><%- mail %></li>';

		wp_localize_script( 'bpmvp_main_script', 'bpmvp', $js_vars);
		wp_enqueue_script( 'bpmvp_main_script' );
		wp_enqueue_style( 'bpmvp_main_style' );
	}

	/**
	 * Register the settings
	 *
	 * @return void
	 */
	function register_settings() {

		register_setting( 'byteplant_email_validator', 'bpmvp_settings' );

		add_settings_section(
			'bpmvp_pluginPage_section',
			__( 'Email Validator Options', 'email-validator-by-byteplant' ),
			array( $this, 'render_section' ),
			'byteplant_email_validator'
		);

		add_settings_field(
			'bpmvp_api_key',
			__( 'API Key', 'email-validator-by-byteplant' ),
			array( $this, 'render_settings_field' ),
			'byteplant_email_validator',
			'bpmvp_pluginPage_section',
			array(
				'id'      => 'apikey',
				'type'    => 'text',
				'key'     => 'bpmvp_api_key',
				'default' => '',
			)
		);

		add_settings_field(
			'bpmvp_reg_check',
			__( 'Validate email on registration', 'email-validator-by-byteplant' ),
			array( $this, 'render_settings_field' ),
			'byteplant_email_validator',
			'bpmvp_pluginPage_section',
			array(
				'id'      => 'reg_check',
				'type'    => 'checkbox',
				'key'     => 'bpmvp_reg_check',
				'default' => 0,
			)
		);

		add_settings_field(
			'bpmvp_comments_check',
			__( 'Validate email for comments', 'email-validator-by-byteplant' ),
			array( $this, 'render_settings_field' ),
			'byteplant_email_validator',
			'bpmvp_pluginPage_section',
			array(
				'id'      => 'comments_check',
				'type'    => 'checkbox',
				'key'     => 'bpmvp_comments_check',
				'default' => 0,
			)
		);

		add_settings_field(
			'bpmvp_is_email_check',
			__( 'Hook to is_email() function', 'email-validator-by-byteplant' ),
			array( $this, 'render_settings_field' ),
			'byteplant_email_validator',
			'bpmvp_pluginPage_section',
			array(
				'id'      => 'is_email_check',
				'type'    => 'checkbox',
				'key'     => 'bpmvp_is_email_check',
				'default' => 0,
			)
		);
	}

	/**
	 * Renders the section area.
	 *
	 * @return void
	 */
	function render_section() {

		echo wp_kses_post( __('You can use <a href="http://www.email-validator.net" target="_blank">our service</a> to validate email addresses in real-time. The email address verification process includes these steps:<br>
			Syntax verification<br>
			DNS validation including MX record lookup<br>
			Disposable email address (DEA) detection<br>
			Misspelled domain detection to prevent Typosquatting<br>
			Freemail address detection<br>
			SMTP connectivity and availability checking<br>
			Temporary unavailability detection<br>
			Mailbox existence checking<br>
			Catch-All testing<br>
			Greylisting detection', 'email-validator-by-byteplant' ) );

		echo '<br><br>';
		echo wp_kses_post( __('You can register for a <a href="http://www.email-validator.net/email-validation-online-api-get-free-trial.html" target="_blank">free API key</a> (limited to 100 address checks).<br>
			If you want to verify more than 100 addresses, please have a look at our pay-as-you-go pricing model and the <a href="http://www.email-validator.net/email-address-verification-pricing.html" target="_blank">subscription plans</a> we offer.', 'email-validator-by-byteplant' ) );

		esc_html_e('To use the email validation in 3rd party forms, add the "bpmvp-mail" class to those inputs of the form that you want to validate and add the following code to the functions.php of your child theme:', 'email-validator-by-byteplant' );

		echo '<textarea rows="3" class="large-text code" disabled>if ( function_exists( \'bpmvp_activate_third_party\' ) ) {
	bpmvp_activate_third_party();
}</textarea>';

	}

	/**
	 * Render a settings field
	 *
	 * @param array $args Specify the field.
	 *
	 * @return void
	 */
	public function render_settings_field( $args ) {
		$default_args = array(
			'id'      => 'apikey',
			'type'    => 'text',
			'key'     => 'bpmvp_api_key',
			'default' => 0,
		);
		$args = wp_parse_args( $args, $default_args );

		$plugin = BPMVP_Plugin::get_instance();
		$option = $plugin->get_option( $args['key'] );
		$value = ( NULL !== $option ) ? $option : $args['default'];

		if ( 'text' === $args['type'] ) :
		?>
		<input
			id="bpmvp_phone_<?php echo esc_attr( $args['key'] ); ?>"
			type="text"
			name="bpmvp_settings[<?php echo esc_attr( $args['key'] ); ?>]"
			value="<?php echo esc_attr( $value ); ?>"
		>
		<?php
		elseif ( 'checkbox' === $args['type'] ) : ?>
		<input
			id="bpmvp_phone_<?php echo esc_attr( $args['key'] ); ?>"
			type="checkbox"
			name="bpmvp_settings[<?php echo esc_attr( $args['key'] ); ?>]"
			value="1"
			<?php checked( $value, 1 ); ?>
		>
		<?php
		endif;

	}

	/**
	 * Access this plugin’s working instance
	 *
	 * @wp-hook plugins_loaded
	 * @return  object of this class
	 */
	public static function get_instance() {

		NULL === self::$instance and self::$instance = new self;

		return self::$instance;
	}


	/**
	 * Empty and protected constructor.
	 */
	protected function __construct() {}

	/**
	 * Empty and private clone.
	 */
	private function __clone(){}

}
